@@ -5,7 +5,7 @@ use vars qw($VERSION);
 use DateTime;
 use Carp;
 
-$VERSION = '0.15.2';
+$VERSION = '0.14';
 
 my %languages = (
     'en'      => {numbers => [qw /one two three four five six seven
@@ -20,7 +20,7 @@ my %languages = (
                   format  => "O ponteiro grande est no %s " .
                              "e o ponteiro pequeno est no %s"},
 
-    'de'      => {numbers => [qw /Eins Zwei Drei Vier Fnf Sechs Sieben
+    'de'      => {numbers => [qw /Eins Zwei Drie Vier Fnf Sechs Sieben
                                        Acht Neun Zehn Elf Zwlf/],
                   format  => "Der gro\xDFe Zeiger ist auf der %s " .
                              "und der kleine Zeiger ist auf der %s",
@@ -212,8 +212,8 @@ DateTime::Format::Baby - Parse and format baby-style time
 
   $Baby->language('fr');
 
-  # La grande aiguille est sur le douze et la petite aiguille est sur le six>
-  $Baby->format_datetime($dt);
+  # Le ...
+  DateTime::Format::ICal->format_datetime($dt);
 
 =head1 DESCRIPTION
 
@@ -264,7 +264,7 @@ more for amusement than anything else.
 
 =head1 AUTHOR
 
-Rick Measham <rickm@cpan.org> (BigLug on PerlMonks)
+Rick Measham <rickm-cpan@isite.net.au> (BigLug on PerlMonks)
 
 This code is a DateTime version of Acme::Time::Baby (copyright 2002 by Abigail)
 with the ability to parse strings added by Rick Measham.
